@@ -30,9 +30,9 @@ typedef struct type_wrap {
 int cgi_pid;
 
 void ALRM_handler() {
-	if (kill(cgi_pid, 15) != -1) {
+	if (kill(cgi_pid, SIGTERM) != -1) {
 		sleep(1);
-		kill(cgi_pid, 9);
+		kill(cgi_pid, SIGKILL);
 	}
 }
 
