@@ -33,8 +33,8 @@ typedef struct type_cgi_info {
 	int to_cgi, from_cgi, cgi_error, highest_fd;
 
 	char *input_buffer, *error_buffer;
-	int input_buffer_size, input_len;
-	int error_buffer_size, error_len;
+	int input_buffer_size, error_buffer_size;
+	size_t input_len, error_len;
 
 	/* Normal CGI
 	 */
@@ -44,7 +44,7 @@ typedef struct type_cgi_info {
 	 */
 	bool read_header;
 	char header[FCGI_HEADER_LENGTH];
-	int fcgi_data_len;
+	size_t fcgi_data_len;
 } t_cgi_info;
 
 int fix_crappy_cgi_headers(t_cgi_info *cgi_info);
