@@ -149,16 +149,6 @@ void touch_logfiles(t_config *config, char *dir) {
 	}
 }
 
-/* Determine the extension of the requested file
- */
-void determine_extension(t_session *session) {
-	if ((session->extension = strrchr(session->file_on_disk, '.')) != NULL) {
-		(session->extension)++;
-	} else {
-		session->extension = session->config->no_extension_as;
-	}
-}
-
 /* Check if the requested file is a CGI program.
  */
 t_cgi_type check_target_is_cgi(t_session *session) {
@@ -229,8 +219,15 @@ int handle_error(t_session *session, int error_code) {
 		memcpy(session->file_on_disk, session->host->website_root, length + 1);
 		strcpy(session->file_on_disk + length, error_handler);
 
+		/* Determine the extension of the error handler
+		 */
+		if ((session->extension = strrchr(session->file_on_disk, '.')) != NULL) {
+			(session->extension)++;
+		} else {
+			session->extension = session->config->no_extension_as;
+		}
+
 		session->cgi_type = no_cgi;
-			
 		check_target_is_cgi(session);
 
 		if (session->cgi_type != no_cgi) {
@@ -615,6 +612,7 @@ int parse_request(t_session *session, int total_bytes) {
 	}
 	session->headerfields = parse_headerfields(str_end + 3);
 	session->hostname = get_headerfield("Host:", session->headerfields);
+	session->cookie = get_headerfield("Cookie:", session->headerfields);
 
 	if ((conn = get_headerfield("Connection:", session->headerfields)) != NULL) {
 		conn = strlower(remove_spaces(conn));
@@ -857,13 +855,13 @@ int serve_client(t_session *session) {
 				return 500;
 			}
 			if (new_uri != NULL) {
+#ifdef DEBUG
+				fprintf(stderr, "Rewrite URL: [%s] --> [%s]\n", session->uri, new_uri);
+#endif
 				if (register_tempdata(&(session->tempdata), new_uri, tc_data) == -1) {
 					free(new_uri);
 					return 500;
 				}
-#ifdef DEBUG
-				fprintf(stderr, "Rewrite URL: [%s] --> [%s]\n", session->uri, new_uri);
-#endif
 				session->uri = new_uri;
 			}
 
@@ -1019,7 +1017,13 @@ int serve_client(t_session *session) {
 		return 301;
 	}
 
-	determine_extension(session);
+	/* Determine the extension of the requested file
+	 */
+	if ((session->extension = strrchr(session->file_on_disk, '.')) != NULL) {
+		(session->extension)++;
+	} else {
+		session->extension = session->config->no_extension_as;
+	}
 
 	if ((session->request_method != PUT) && (session->request_method != DELETE)) {
 		check_target_is_cgi(session);
@@ -1609,7 +1613,7 @@ int run_server(t_settings *settings) {
 
 		access_rights = 01733;
 		if (status.st_uid != 0) {
-			if (getuid() == 0) {
+			if ((getuid() == 0) || (geteuid() == 0)) {
 				if (chown(config->upload_directory, 0, 0) == -1) {
 					perror("chown(UploadDirectory, 0, 0)");
 					return EXIT_FAILURE;
@@ -1670,7 +1674,7 @@ int run_server(t_settings *settings) {
 
 	/* Change userid
 	 */
-	if (getuid() == 0) do {
+	if ((getuid() == 0) || (geteuid() == 0)) do {
 		if (setgroups(config->groups.number, config->groups.array) != -1) {
 			if (setgid(config->server_gid) != -1) {
 				if (setuid(config->server_uid) != -1) {
