@@ -50,6 +50,13 @@ typedef struct type_tempdata {
 	struct type_tempdata *next;
 } t_tempdata;
 
+typedef struct type_ipcounterlist {
+	t_ip_addr ip;
+	int count;
+	
+	struct type_ipcounterlist *next;
+} t_ipcounterlist;
+
 void sfree(void* ptr);
 
 t_headerfield *parse_headerfields(char *line);
