@@ -8,7 +8,7 @@
 
 #define MAX_VALUE (INT_MAX - 10) / 10
 
-/* Convert a string to a integer.
+/* Convert a string to an integer.
  */
 int str2int(const char *str) {
 	int i = 0, value = 0;
@@ -271,7 +271,7 @@ bool forbidden_chars_present(char *str) {
 		} else if (*str == '%') {
 			if ((high = hex_to_int(*(str + 1))) != -1) {
 				if ((low = hex_to_int(*(str + 2))) != -1) {
-					if (((high<<4) + low) < 32) {
+					if (((high << 4) + low) < 32) {
 						return true;
 					}
 				}
@@ -285,7 +285,7 @@ bool forbidden_chars_present(char *str) {
 
 /* Prevent Command injection.
  */
-int prevent_CMDi(char *str) {
+int prevent_cmdi(char *str) {
 	int result = 0;
 	short low, high;
 	char value;
@@ -322,7 +322,7 @@ int prevent_CMDi(char *str) {
 
 /* Prevent SQL injection
  */
-int prevent_SQLi(char *str, int length, char **newstr) {
+int prevent_sqli(char *str, int length, char **newstr) {
 	int changed = 0, i, add, left, newlength = 0;
 	char *temp, value;
 	short low, high;
@@ -332,7 +332,7 @@ int prevent_SQLi(char *str, int length, char **newstr) {
 	}
 
 	add = left = 32;
-	if ((*newstr = (char*)malloc(length + add)) == NULL) {
+	if ((*newstr = (char*)malloc(length + add + 1)) == NULL) {
 		return -1;
 	}
 	for (i = 0; i < length; i++) {
@@ -350,7 +350,7 @@ int prevent_SQLi(char *str, int length, char **newstr) {
 			*(*newstr + newlength++) = '\\';
 			if (left-- == 0) {
 				add += left = 32;
-				if ((temp = (char*)realloc(*newstr, length + add)) == NULL) {
+				if ((temp = (char*)realloc(*newstr, length + add + 1)) == NULL) {
 					free(*newstr);
 					return -1;
 				} else {
@@ -366,6 +366,8 @@ int prevent_SQLi(char *str, int length, char **newstr) {
 		free(*newstr);
 		*newstr = NULL;
 		newlength = 0;
+	} else {
+		*(*newstr + newlength) = '\0';
 	}
 
 	return newlength;
@@ -373,7 +375,7 @@ int prevent_SQLi(char *str, int length, char **newstr) {
 
 /* Prevent cross-site scripting.
  */
-int prevent_XSS(char *str) {
+int prevent_xss(char *str) {
 	int result = 0;
 	short low, high;
 	char value;
