@@ -13,9 +13,9 @@ bool valid_uri(char *uri);
 int  url_encode(char *str, char **encoded);
 void url_decode(char *str);
 bool forbidden_chars_present(char *str);
-int  prevent_CMDi(char *str);
-int  prevent_SQLi(char *str, int length, char **newstr);
-int  prevent_XSS(char *str);
+int  prevent_cmdi(char *str);
+int  prevent_sqli(char *str, int length, char **newstr);
+int  prevent_xss(char *str);
 const char *http_error(int code);
 bool decode_base64(char *base64);
 int  str_replace(char *src, char *from, char *to, char **dst);
