@@ -344,7 +344,7 @@ int main(int argc, char *argv[]) {
 						line[len - 1] = '\0';
 					}
 					if ((pid = (pid_t)str2int(line)) > 1) {
-						if (kill(pid, 15) == -1) {
+						if (kill(pid, SIGTERM) == -1) {
 							fprintf(stderr, "kill -15 ");
 							perror(line);
 						}
