@@ -90,6 +90,7 @@ static t_host *new_host(void) {
 		host->prevent_cmdi       = false;
 		host->prevent_sqli       = false;
 		host->prevent_xss        = false;
+		host->prevent_csrf       = false;
 		host->follow_symlinks    = false;
 		host->enable_path_info   = false;
 		host->trigger_on_cgi_status = true;
@@ -340,7 +341,7 @@ static bool valid_file(char *file) {
 }
 
 static bool valid_directory(char *dir) {
-	int len;
+	size_t len;
 
 	if (dir == NULL) {
 		return false;
@@ -1152,6 +1153,10 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_yesno(value, &(host->prevent_cmdi)) == 0) {
 			return true;
 		}
+	} else if (strcmp(key, "preventcsrf") == 0) {
+		if (parse_yesno(value, &(host->prevent_csrf)) == 0) {
+			return true;
+		}
 	} else if (strcmp(key, "preventsqli") == 0) {
 		if (parse_yesno(value, &(host->prevent_sqli)) == 0) {
 			return true;
@@ -1219,7 +1224,7 @@ static bool host_setting(char *key, char *value, t_host *host) {
 
 static bool directory_setting(char *key, char *value, t_directory *directory) {
 	char *maxclients;
-	int length;
+	size_t length;
 
 	if (strcmp(key, "accesslist") == 0) {
 		if ((directory->access_list = parse_accesslist(value, true, directory->access_list)) != NULL) {
