@@ -130,7 +130,7 @@ typedef struct type_directory {
 
 typedef struct type_host {
 	char          *website_root;
-	int           website_root_len;
+	size_t        website_root_len;
 	char          *start_file;
 	char          *error_401_handler;
 	char          *error_403_handler;
@@ -180,6 +180,7 @@ typedef struct type_host {
 	bool          prevent_cmdi;
 	bool          prevent_sqli;
 	bool          prevent_xss;
+	bool          prevent_csrf;
 	bool          follow_symlinks;
 	bool          enable_path_info;
 	bool          trigger_on_cgi_status;
@@ -252,7 +253,7 @@ typedef struct type_config {
 	t_fcgi_server *fcgi_server;
 
 	char          *upload_directory;
-	int           upload_directory_len;
+	size_t        upload_directory_len;
 	bool          create_upload_dir;
 
 #ifdef HAVE_CACHE
