@@ -407,6 +407,46 @@ bool client_is_rejected_bot(t_session *session) {
 	return false;
 }
 
+/* Prevent Cross-site Request Forgery
+ */
+int prevent_csrf(t_session *session) {
+	char *referer, *slash;
+	int i, n;
+
+	if (strcmp(session->method, "POST") != 0) {
+		return 0;
+	}
+
+	if ((referer = get_headerfield("Referer:", session->headerfields)) == NULL) {
+		return 0;
+	}
+	
+	if (strncmp(referer, "http://", 7) == 0) {
+		referer += 7;
+	} else if (strncmp(referer, "https://", 8) == 0) {
+		referer += 8;
+	} else {
+		session->cookie = NULL;
+		return 1;
+	}
+	
+	if ((slash = strchr(referer, '/')) != NULL) {
+		n = slash - referer;
+	} else {
+		n = strlen(referer);
+	}
+
+	for (i = 0; i < session->host->hostname.size; i++) {
+		if (strncasecmp(referer, *(session->host->hostname.item + i), n) == 0) {
+			return 0;
+		}
+	}
+
+	session->cookie = NULL;
+
+	return 1;
+}
+
 void close_socket(t_session *session) {
 	if (session->socket_open) {
 #ifdef HAVE_SSL
