@@ -509,16 +509,22 @@ int execute_cgi(t_session *session) {
 	}
 
 	if (session->host->prevent_xss) {
-		/* Prevent Cross-site scripting
+		/* Prevent Cross-site Scripting
 		 */
-		prevent_XSS(session->vars);
+		prevent_xss(session->vars);
+	}
+
+	if (session->host->prevent_csrf) {
+		/* Prevent Cross-site Request Forgery
+		 */
+		prevent_csrf(session);
 	}
 
 	if (session->host->prevent_sqli) {
 		/* Prevent SQL injection
 		 */
 		if (session->vars != NULL) {
-			switch (prevent_SQLi(session->vars, strlen(session->vars) + 1, &line)) {
+			switch (prevent_sqli(session->vars, strlen(session->vars), &line)) {
 				case -1:
 					return 500;
 				case 0:
@@ -538,7 +544,7 @@ int execute_cgi(t_session *session) {
 		}
 
 		if (session->body != NULL) {
-			switch (result = prevent_SQLi(session->body, session->content_length, &line)) {
+			switch (result = prevent_sqli(session->body, session->content_length, &line)) {
 				case -1:
 					return 500;
 				case 0:
@@ -558,8 +564,8 @@ int execute_cgi(t_session *session) {
 			}
 		}
 
-		if ((session->cookie = get_headerfield("Cookie:", session->headerfields)) != NULL) {
-			switch (prevent_SQLi(session->cookie, strlen(session->cookie) + 1, &line)) {
+		if (session->cookie != NULL) {
+			switch (prevent_sqli(session->cookie, strlen(session->cookie), &line)) {
 				case -1:
 					return 500;
 				case 0:
@@ -582,10 +588,10 @@ int execute_cgi(t_session *session) {
 	if (session->host->prevent_cmdi) {
 		/* Prevent Command injection
 		 */
-		if ((prevent_CMDi(session->vars) > 0) && (session->config->ban_on_cmdi > 0)) {
+		if ((prevent_cmdi(session->vars) > 0) && (session->config->ban_on_cmdi > 0)) {
 			return rr_CMD_INJECTION;
 		}
-		if ((prevent_CMDi(session->cookie) > 0) && (session->config->ban_on_cmdi > 0)) {
+		if ((prevent_cmdi(session->cookie) > 0) && (session->config->ban_on_cmdi > 0)) {
 			return rr_CMD_INJECTION;
 		}
 		/*
