@@ -13,5 +13,8 @@ int handle_options_request(t_session *session);
 int handle_trace_request(t_session *session);
 int handle_put_request(t_session *session);
 int handle_delete_request(t_session *session);
+#ifdef HAVE_XSLT
+int handle_xml_file(t_session *session);
+#endif
 
 #endif
