@@ -66,13 +66,13 @@ static void add_headerfield(t_session *session, const char **params, char *heade
 	}
 }
 
-static void add_parameter_line(const char **params, char *line, char *prefix, int *i) {
+static void add_parameter_line(const char **params, char *line, char split, char *prefix, int *i) {
 	char *item, *key, *value, name[MAX_NAME_LEN + 1];
 	size_t prefix_len;
 
 	prefix_len = strlen(prefix);
 	while (line != NULL) {
-		split_string(line, &item, &line, '&');
+		split_string(line, &item, &line, split);
 		if (split_string(item, &key, &value, '=') == -1) {
 			continue;
 		} else if (prefix_len + strlen(key) > MAX_NAME_LEN) {
@@ -90,7 +90,7 @@ static const char **get_transform_parameters(t_session *session) {
 	const char **params;
 	int i = 0;
 	char ip[MAX_IP_STR_LEN];
-	char value[20], *cookie;
+	char value[20];
 
 	if ((params = (const char**)malloc(sizeof(void*) * (MAX_PARAMETERS + 1))) != NULL) {
 		add_parameter(params, "REQUEST_METHOD", session->method, &i);
@@ -151,13 +151,9 @@ static const char **get_transform_parameters(t_session *session) {
 			add_headerfield(session, params, "Content-Type:", "CONTENT_TYPE", &i);
 		}
 
-		add_parameter_line(params, session->vars, "GET_", &i);
-		add_parameter_line(params, session->body, "POST_", &i);
-		if (session->cookie != NULL) {
-			add_parameter_line(params, session->cookie, "COOKIE_", &i);
-		} else if ((cookie = get_headerfield("Cookie:", session->headerfields)) != NULL) {
-			add_parameter_line(params, cookie, "COOKIE_", &i);
-		}
+		add_parameter_line(params, session->vars, '&', "GET_", &i);
+		add_parameter_line(params, session->body, '&', "POST_", &i);
+		add_parameter_line(params, session->cookie, ';', "COOKIE_", &i);
 
 		params[i] = NULL;
 	}
